@@ -13,8 +13,8 @@ class MixNet(nn.Module):
         self.linear_h2w = nn.Linear(hidden_size, 2)
 
     def forward(self, x_a, x_b):
-        x_a = self.subnet_a(x_a)
-        x_b = self.subnet_b(x_b)
+        y_a = self.subnet_a(x_a)
+        y_b = self.subnet_b(x_b)
 
         x_w = F.tanh(self.linear_i2h(torch.cat([x_a, x_b], dim=-1)))
         x_w = F.sigmoid(self.linear_h2w(x_w))
@@ -24,13 +24,13 @@ class MixNet(nn.Module):
         # x_w => batch_size * 2
         x_w_a, x_w_b = x_w.split(1, dim=-1)
         x_w_a = x_w_a.expand(dim=-1)
-        x_a = torch.mm(x_a, x_w_a)
+        y_a = torch.mm(y_a, x_w_a)
         x_w_b = x_w_b.expand(dim=-1)
-        x_b = torch.mm(x_b, x_w_b)
+        y_b = torch.mm(y_b, x_w_b)
 
-        return x_a + x_b
+        return y_a + y_b
 
-    def predict(self, x):
+    def predict(self, x_a, x_b):
         # y_a, y_b = self.forward(x)
         y = self.forward(x_a, x_b)
         return torch.argmax(y, 1)
\ No newline at end of file
